<?php

namespace MyFastApp;

class Helper
{
    /**
     * Convert a rgba(r,g,b,a) string to ARGB hex string #AARRGGBB
     * If a color is already in hex format, it return it untouched
     * @param $color rgba( R, G , B, A) string
     * @return string ARGB color in hex format
     */
    public static function argb2hex($inputColor)
    {
        $color = trim($inputColor);

        if (strpos($color, "rgba") === false)
            return $inputColor;

        $regex = "#\((([^()]+|(?R))*)\)#";
        if (preg_match_all($regex, $color, $matches)) {
            $rgba = explode(",", implode(" ", $matches[1]));
        } else {
            $rgba = explode(",", $color);
        }

        $rr = self::decToHex($rgba["0"], 2);
        $gg = self::decToHex($rgba["1"], 2);
        $bb = self::decToHex($rgba["2"], 2);
        $aa = "";

        if (array_key_exists("3", $rgba)) {
            $aa = self::decToHex($rgba["3"] * 255, 2);
        }

        return strtoupper("#$aa$rr$gg$bb");
    }

    /**
     * @param $input Decimal representation of a integer
     * @param int $minimumDigitsNumber Minimun number of digits
     * @return string Hex representation with the required number of digits
     */
    private static function decToHex($input, $minimumDigitsNumber = 2)
    {
        return str_pad(dechex($input), $minimumDigitsNumber, "0", STR_PAD_LEFT);
    }
}
